@@ -30,7 +30,6 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-from __future__ import print_function
 from smartcard.scard import *
 
 
@@ -65,5 +64,5 @@ if __name__ == '__main__':
     cs = CardService(cc)
     cs.connection.connect()
     data, sw1, sw2 = cs.connection.transmit(SELECT + DF_TELECOM)
-    print("%X %X" % (sw1, sw2))
+    print("{:X} {:X}".format(sw1, sw2))
     cs.connection.disconnect()
